==> kdevelop_5.2.1.orig.tar.xz: kdevelop-5.2.1/kdevplatform/vcs/vcsjob.cpp <==
/***************************************************************************
 *   This file is part of KDevelop                                         *
 *   Copyright 2007 Andreas Pakulat <apaku@gmx.de>                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#include "vcsjob.h"

//#include <KLocalizedString>

namespace KDevelop {

class VcsJobPrivate
{
public:
    VcsJob::JobType m_type;
};

VcsJob::VcsJob( QObject* parent, OutputJobVerbosity verbosity )
    : OutputJob(parent, verbosity), d(new VcsJobPrivate)
{
    d->m_type = Unknown;
    setStandardToolView(IOutputView::VcsView);

    if(verbosity == Verbose) {
        QMetaObject::invokeMethod(this, "delayedModelInitialize", Qt::QueuedConnection);
    }
}

void VcsJob::delayedModelInitialize()
{
    startOutput();
}

VcsJob::~VcsJob() = default;

VcsJob::JobType VcsJob::type() const
{
    return d->m_type;
}

void VcsJob::setType( VcsJob::JobType t )
{
    d->m_type = t;
}

}

==> kdevelop-5.4.80.tar.xz: kdevelop-5.4.80/kdevplatform/vcs/vcsjob.cpp <==
/***************************************************************************
 *   This file is part of KDevelop                                         *
 *   Copyright 2007 Andreas Pakulat <apaku@gmx.de>                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#include "vcsjob.h"

//#include <KLocalizedString>

namespace KDevelop {

class VcsJobPrivate
{
public:
    VcsJob::JobType m_type;
};

VcsJob::VcsJob( QObject* parent, OutputJobVerbosity verbosity )
    : OutputJob(parent, verbosity)
    , d_ptr(new VcsJobPrivate)
{
    Q_D(VcsJob);

    d->m_type = Unknown;
    setStandardToolView(IOutputView::VcsView);

    if(verbosity == Verbose) {
        QMetaObject::invokeMethod(this, "delayedModelInitialize", Qt::QueuedConnection);
    }
}

void VcsJob::delayedModelInitialize()
{
    startOutput();
}

VcsJob::~VcsJob() = default;

VcsJob::JobType VcsJob::type() const
{
    Q_D(const VcsJob);

    return d->m_type;
}

void VcsJob::setType( VcsJob::JobType t )
{
    Q_D(VcsJob);

    d->m_type = t;
}

}
